#
# Sesame
#

__title__ = 'sesame'
__version__ = '0.2.0'
__build__ = 0x000020
__author__ = 'Matt Black'
__license__ = 'Simplified BSD License'
__copyright__ = 'Copyright 2013 Matt Black'

try:
    import core
except ImportError:
    pass
